const USER_PERMISSIONS = require('../models/user').USER_PERMISSIONS;

/**
 * Middleware de route qui ne laisse l'accès qu'aux utilisateurs
 * qualifiés par la condition donnée en paramètre.
 *
 * En cas d'autorisations insuffisantes l'utilisateur est redirigé vers la page
 * d'accueil avec un message d'erreur.
 * Ce middleware est à utiliser avant la véritable fonction de route.
 *
 * @param {string} requiredPermissionLevel
 *    le niveau de permission requis pour accéder à la ressource
 * @return {Function}
 *    une fonction Express-friendly pour garder la chaîne intacte
 */
function checkPermissions(requiredPermissionLevel) {
  return function(req, res, next) {
    const requestEmitterPermissionLevel =
      USER_PERMISSIONS[(req.user && req.user.role) || 'NOBODY'];

    // User doesn't have required permissions to access this route
    if (requestEmitterPermissionLevel < requiredPermissionLevel) {
      req.flash(
          'info',
          'Vous n\'avez pas les autorisations requises' +
          ' pour accéder à cette ressource',
      );
      res.redirect('/');
    } else {
      next();
    }
  };
}

module.exports = {
  checkPermissions,
};
